# Chapter 4
library(lavaan)

Data <- read.table("WERS_Mplus_final.csv", header = FALSE)
names(Data) <- c("compid", "persid", "hw1", "hw2", "hw3", 
                 "re1", "re2", "skl", "pay",  "mnemps")
Data[ Data == -999 ] <- NA

Data$nem <- log(Data$mnemps)



# Figure 4.2
model <- '
  level: 1
    res =~ re1 + re2
    har =~ hw1 + hw2 + hw3
    skl ~ pay + resskl*res + hardskl*har
    har ~ pay + reshard*res
    res ~~ pay

  level: 2
    skl ~ nem

  # defined parameters
  ie := hardskl*reshard
  total := ie + resskl
'

fit <- sem(model, data = Data, cluster = "compid", estimator = "MLR",
           fixed.x = FALSE)
summary(fit, fit.measures = TRUE, standardized = TRUE)

# Figure 4.3
model <- '
  level: 1
    res =~ re1 + re2
    har =~ hw1 + hw2 + hw3
    skl ~ gamma01*pay + resskl*res + hardskl*har
    har ~ pay + reshard*res
    pay ~~ pay
    res ~~ pay

  level: 2
    pay ~~ pay
    skl ~ nem + gamma10*pay
    pay ~~ nem

  # defined parameters
  betac := gamma10-gamma01
  ie := hardskl*reshard
'

fit <- sem(model, data = Data, cluster = "compid", estimator = "MLR",
           fixed.x = FALSE)
summary(fit, fit.measures = TRUE, standardized = TRUE)

# Figure 4.5
model <- '
  level: 1
    res =~ re1 + re2
    har =~ hw1 + hw2 + hw3
    skl ~ gamma01*pay + resskl*res + hardskl*har
    har ~ pay + reshard*res
    pay ~~ pay
    res ~~ pay

  level: 2
    reb =~ re1 + re2
    hab =~ hw1 + hw2 + hw3

    skl ~ nem + reb + hab + pay

    pay ~~ pay
    pay ~~ nem

    hab ~ reb + nem + pay
    reb ~ nem
'

fit <- sem(model, data = Data, cluster = "compid", estimator = "MLR",
           fixed.x = FALSE)
summary(fit, fit.measures = TRUE, standardized = TRUE)


# Figure 4.6
model <- '
  level: 1
    res =~ re2 + i1*re1
    har =~ hw1 + i2*hw2 + i3*hw3

    skl ~ gamma01*pay + gamma02*res + gamma03*har
    har ~ gamma04*res + pay

    res ~~ pay

  level: 2
    reb =~ re2 + i1*re1
    hab =~ hw1 + i2*hw2 + i3*hw3

    skl ~ nem + gamma20*reb + gamma30*hab + gamma10*pay

    pay ~~ pay
    pay ~~ nem

    hab ~ gamma40*reb + nem + pay
    reb ~ nem

    # defined parameters
    betac1 := gamma01 - gamma10
    betac2 := gamma02 - gamma20
    betac3 := gamma03 - gamma30
    betac4 := gamma04 - gamma40
'

fit <- sem(model, data = Data, cluster = "compid", estimator = "MLR",
           fixed.x = FALSE)
summary(fit, fit.measures = TRUE, standardized = TRUE)









